##  Understand the Meta Model
The SAP LeanIX meta model is a conceptual framework that defines the structure and relationships of architectural elements within an organization’s enterprise architecture landscape. It consists of various fact sheet types (such as application, IT component, business capability, and more) and the relations between them. This model serves as a comprehensive blueprint for organizing and interconnecting information about your enterprise architecture.
To get started, explore the key fact sheet types included in the meta model and see modeling best practices. For detailed information, see [Meta Model](https://help.sap.com/docs/leanix/ea/meta-model?locale=en-US&state=PRODUCTION&version=CLOUD "Get an overview of the SAP LeanIX meta model and its key concepts.").
